From: Rhett Garber <rhettg@gmail.com>
To: Havasvölgyi Ottó <h.otto@freemail.hu>
Cc: pgsql-performance@postgresql.org
Subject: Re: Why hash join instead of nested loop?
Date: Fri, 5 Aug 2005 16:16:51 -0700
Message-ID: <41b0fe8905080516164464e04f@mail.gmail.com> (raw)
In-Reply-To: <001801c59a0a$f4be7480$9a00a8c0@OTTO>
References: <41b0fe890508051135712a086b@mail.gmail.com>
<001801c59a0a$f4be7480$9a00a8c0@OTTO>
On 8/5/05, Havasvölgyi Ottó <h.otto@freemail.hu> wrote:
> Please post the explain analyze for both queries. From that we can see the
> predicted and the actual costs of them.
> select rtmessagestate.* from rtmessagestate, connection where
> connection_registry_id = 40105 and obj1 = 73582 and obj2 =
> rtmessagestate.id;
Hash Join (cost=5.96..7.04 rows=1 width=14) (actual
time=10.591..10.609 rows=1 loops=1)
Hash Cond: ("outer".id = "inner".obj2)
-> Seq Scan on rtmessagestate (cost=0.00..1.05 rows=5 width=14)
(actual time=0.011..0.022 rows=5 loops=1)
-> Hash (cost=5.96..5.96 rows=1 width=4) (actual
time=0.109..0.109 rows=0 loops=1)
-> Index Scan using connection_regid_obj1_index on
connection (cost=0.00..5.96 rows=1 width=4) (actual time=0.070..0.076
rows=1 loops=1)
Index Cond: ((connection_registry_id = 40105) AND (obj1
= 73582)) Total runtime: 11.536 ms
(7 rows)
> select rtmessage.id, subject from rtmessage, connection where
> connection_registry_id = 40003 and obj1 = 4666 and obj2 =
> rtmessage.id;
Nested Loop (cost=0.00..11.62 rows=2 width=38) (actual
time=0.186..0.970 rows=12 loops=1)
-> Index Scan using connection_regid_obj1_index on connection
(cost=0.00..5.96 rows=1 width=4) (actual time=0.109..0.308 rows=12
loops=1)
Index Cond: ((connection_registry_id = 40003) AND (obj1 = 4666))
-> Index Scan using rtmessage_pkey on rtmessage (cost=0.00..5.65
rows=1 width=38) (actual time=0.032..0.039 rows=1 loops=12)
Index Cond: ("outer".obj2 = rtmessage.id)
Total runtime: 1.183 ms
(6 rows)
Rhett
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: rhettg@gmail.com, h.otto@freemail.hu
Subject: Re: Why hash join instead of nested loop?
In-Reply-To: <41b0fe8905080516164464e04f@mail.gmail.com>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox